@@ -28,7 +28,6 @@ class ClauseInfo[T: tp.Type[Table]]:
         self._alias: tp.Optional[str] = self._alias_children_resolver(self)
 
         self._query: str = self.__create_value_string(self._column)
-        pass
 
     def __repr__(self) -> str:
         return f"{ClauseInfo.__name__}: {self.query}"
@@ -45,6 +44,13 @@ class ClauseInfo[T: tp.Type[Table]]:
     def query(self) -> str:
         return self._query
 
+    @property
+    def dtype[TProp](self) -> tp.Optional[tp.Type[TProp]]:
+        try:
+            return self._table.get_column(self.column).dtype
+        except ValueError:
+            return None
+
     def _resolve_column(self, data: ClauseDataType) -> str:
         if isinstance(data, property):
             return self._table.__properties_mapped__[data]
@@ -74,6 +80,17 @@ class ClauseInfo[T: tp.Type[Table]]:
 
 
 class DecompositionQueryBase[T: tp.Type[Table]](IDecompositionQuery[T]):
+    @tp.overload
+    def __init__[*Ts](self, table: T, lambda_query: tp.Callable[[T], tuple[*Ts]]) -> None: ...
+    @tp.overload
+    def __init__[*Ts](self, table: T, lambda_query: tp.Callable[[T], tuple[*Ts]], *, alias: bool = ...) -> None: ...
+    @tp.overload
+    def __init__[*Ts](self, table: T, lambda_query: tp.Callable[[T], tuple[*Ts]], *, alias: bool = ..., alias_name: tp.Optional[str] = ...) -> None: ...
+    @tp.overload
+    def __init__[*Ts](self, table: T, lambda_query: tp.Callable[[T], tuple[*Ts]], *, alias: bool = ..., alias_name: tp.Optional[str] = ..., by: JoinType = ...) -> None: ...
+    @tp.overload
+    def __init__[*Ts](self, table: T, lambda_query: tp.Callable[[T], tuple[*Ts]], *, alias: bool = ..., alias_name: tp.Optional[str] = ..., by: JoinType = ..., replace_asterisk_char: bool = ...) -> None: ...
+
     def __init__[*Ts](
         self,
         table: T,
@@ -99,6 +116,11 @@ class DecompositionQueryBase[T: tp.Type[Table]](IDecompositionQuery[T]):
 
         self.__clauses_list_generetor(lambda_query)
 
+    def __getitem__(self, key: str) -> ClauseInfo:
+        for clause in self._all_clauses:
+            if clause.alias == key:
+                return clause
+
     def alias_children_resolver[Tclause: tp.Type[Table]](self, clause_info: ClauseInfo[Tclause]):
         DEFAULT_ALIAS: str = f"{clause_info._table.__table_name__}_{clause_info._column}"
 
